#include "chatManager.as"
#include "terrainEditor.as"
#include "gameScriptWrapper.as"
#include "welcome.as"
#include "streamValidation.as"
#include "botAPI.as"
#include "kickNotificationWrapper.as"

// Create a chatManager object instance
chatManager chatSystem();



// Create a gameScriptManager object instance.
gameScriptManager gsm();



// Add the autoModerator plugin.
// This plugin allows the following commands:
//     - !suspendchat   Suspend all chat traffic for a certain time
//     - !schat         Short for !suspendchat
//     - !chatban       Blocks all chat messages from a certain user for a
//                      certain time
//     - !cban          Short for !chatban
//     - !temporaryban  Not yet implemented
//     - !tempban       Short for !temporaryban
//     - !tban       Short for !temporaryban
// Furthermore, it adds the profanity filter and flood filter to the chat.
chatPlugin_autoModerator autoModerator(@chatSystem);

// This small plugin transform messages like:
//      Anonymous: OMG LOOK ATZ ME
// to:
//      Anonymous: Omg look atz me
chatPlugin_disallowAllUpperCase disallowAllUpperCase(@chatSystem);

// This plugin adds the following commands:
//     - !afk           Prints "<username> is now away from keyboard."
//     - !back          Prints "<username> is now back."
//     - !gtg           Prints "<username> has got to go."
//     - !brb           Prints "<username> will be right back."
chatPlugin_miscellaneousCommands miscellaneousCommands(@chatSystem);

// This command adds the !move command, which will move your avatar in the
// specified direction.
chatPlugin_moveCommand moveCommand(@chatSystem);

// This commands adds the !goto, !setgoto (!sgoto) and !delelegoto (!dgoto)
// command. It allows you to store the position of your avatar (!setgoto <name>)
// and later teleport to that position (!goto <name>).
// Note: The !setgoto command works only with RoR 0.39! (not with 0.38)
chatPlugin_gotoCommand gotoCommand(@chatSystem, @gsm);

// This keeps track of what terrains are being used on the server and gives a
// list when the !terrainlist (!tlist) command is used.
// Note: All clients with RoR 0.38 will be shown as 'unknown terrain'.
chatPlugin_terrainList terrainList(@chatSystem, @gsm);

// This checks the latency of all RoR 0.39 players every 20 seconds and responds
// to !ping commands.
chatPlugin_ping ping(@chatSystem, @gsm);

// Another example, to show how to add commands.
// This adds a command !boost that gives a temporary boost to the truck of
// the user.
customCommand boostCommand(@chatSystem, "boost", customCommand_boost);
void customCommand_boost(chatMessage@ cmsg)
{
	cmsg.privateGameCommand.boostCurrentTruck(2);
}
// Extra boost commands
customCommand boost2Command(@chatSystem, "boost2", customCommand_boost2);
void customCommand_boost2(chatMessage@ cmsg)
{
	cmsg.privateGameCommand.boostCurrentTruck(5);
}
customCommand boost3Command(@chatSystem, "boost3", customCommand_boost3);
void customCommand_boost3(chatMessage@ cmsg)
{
	cmsg.privateGameCommand.boostCurrentTruck(8);
}
customCommand boost4Command(@chatSystem, "boost4", customCommand_boost4);
void customCommand_boost4(chatMessage@ cmsg)
{
	cmsg.privateGameCommand.boostCurrentTruck(10);
}


// Add the terrain editor (RoR 0.39 only!)
// Commented out, doesn't work correctly yet.
//terrainEditor ternnditor(@chatSystem, @gsm);



// Load the terrain edits
terrainFileLoader terrain(@gsm, server.getServerTerrain());



// Add some commands that allow you to reload the terrain file, without having to restart the server.
customCommand reloadTerrainCommand(@chatSystem, "reloadterrain", customCommand_reloadTerrain, null, true, AUTH_ADMIN);
void customCommand_reloadTerrain(chatMessage@) { terrain.reload(); }

customCommand unloadTerrainCommand(@chatSystem, "unloadterrain", customCommand_unloadTerrain, null, true, AUTH_ADMIN);
void customCommand_unloadTerrain(chatMessage@) { terrain.unload(); }

customCommand loadTerrainCommand(@chatSystem, "loadterrain", customCommand_loadTerrain, null, true, AUTH_ADMIN);
void customCommand_loadTerrain(chatMessage@)   { terrain.load();   }

// This is a list of stream names that will not be broadcasted 
array<string>  streamFilterList =  
{ 
	"2004HummerH2.truck","camry.truck","m3e93_gold.truck","2010_Chevy_Camaro_SS.truck","chevysilveradonascar.truck","chevysilveradonascarsuper.truck","svtraptor.truck","RenoClio.truck","Ferarri_458_Spider.truck","bmw750i1.truck","bmw750i2.truck","bmw750i3.truck","chevysilverado2.truck","chevysilverado2mud.truck","chevysilverado2500.truck","chevysilverado2500lifted.truck","chevysilverado3500.truck","gavrilmv4police.truck","gavrilmv4PoliceInterceptor.truck","gavrilmv4rpolice.truck","gavrilmv4RUSSIANPOLICE.truck","gavrilmv4sunmarkedpolice.truck","BoxDodgeRamEXT222.truck","svtraptoroffroadv1.truck","svtraptoroffroadv2.truck","gavril_monster_energy.truck","gavril_monster_energy1.truck","spacewagon_lhd.truck","forester.truck","foc07.truck","nissanr34.truck","camry97.truck","cvev.truck","2115.truck","vaz2.truck","vol.truck","ferrari_458_spider.truck","chevelle.truck","MMCP-C.truck","reven.truck","merc.truck","lincoln.truck","koenigsegg.truck","funnytex.truck","funnytex2.truck","hummerh.truck","focus.truck","Supra92.truck","BeastyG2.truck","Mafioso.truck","DatSwaqqerStickerBomber.truck","TriggerFinger.truck","bcgtpm.truck","gavrilmv4Di1.truck","gavrilmv4Di12.truck","gavrilmv4_ret.truck","gavrilluxury.truck","gavrilmv4_n24.truck","gavrilmv4_nur.truck","gavrilmv4_xd1.truck","gavrilmv4r_POLICe.truck","pri.truck","Peugeot406.truck","1997HondaCivicType-R.truck","gazel.truck","gavrilgv3_DRAG.truck","Ferrari1989F40Competizione.truck","daytonahazzard.truck","ATV.truck","1983AudiSportquattro.truck","1990_BMW_M5_E34.truck","tt.truck","2012Mercedes-BenzS65AMG[W221].truck","Niva.truck","2114u.truck","buffalo.truck","buffaloP.truck","20.truck","tax.truck","sultan.truck","gavrilmv4_jdm.truck","chevy10blazer.truck","ICCE300Meshed_Beta2L.truck","ICCE300Meshed_Beta3AGV_1.truck","private1.truck","private2.truck","private3.truck","GCPS-2016BluebirdVision.truck","GCPS-2016BluebirdVision_white.truck","GCPS-2016BluebirdVision_y.truck","GCPS-2016BluebirdVision_wy.truck","GCPS-2016BluebirdVision_s.truck","GCPS-2016BluebirdVision_white_S.truck","GCPS-2016BluebirdVision_wy_s.truck","GCPS-2016BluebirdVision_y_s.truck","JH-AmtranB800.truck","JH-Amtran3800.truck","JH-Amtran3800SED.truck","JH-AmtranB800SED.truck","1999ThomasMVPERFPS.truck","2007ThomasC2FPS.truck","2007ThomasC2.truck","2009BBA3RE.truck","2010ICCE.truck","2010ICCEFPS.truck","2013BBT3FE.truck","2013ThomasEFX.truck","2013ThomasEFXFPS.truck","2011BBA3.truck","2000BBFS65.truck","2001BB3800.truck","2006BBICCE.truck","2013BBV.truck","2002A3CCS3502JH.truck","moskvich412.truck","02CrownVicPoliceUnmarked.truck","06chargerunmarked.truck","12policecharger.truck","2011FordTarusSlicktop.truck","06policeimpala.truck","2011FordTaruPolice.truck","C2(40).truck","8552008BBVPBCRET.truck","dcds.truck","impala.truck","daytona.truck","AMC_Javelin2.truck","amcpacer.truck","ae86_compom.truck","silvias13.truck","silvias13DriftTune.truck","honda97.truck","r33.truck","subaru22.truck","2001su.truck","rx7.truck","nissanR34.truck","2010Shelbygt500.truck","lexusis300.truck","hondansxgt.truck","su05.truck","su05-2.truck","chevyimpala.truck","chevyimpalanowheels.truck","f430_scu.truck","2008su.truck","m3e92.truck","m3e92_gold.truck","2009DodgeChallengerSRT8(fps).truck","2009DodgeChallengerSRT8.truck","jeep_.truck","mazda3.truck","2010ChevyCamaroSS.truck","x5.truck","vwtour.truck","11'porsche911gt3.truck","Buggati.truck","suzuki.truck","12Mazda_RX8.truck","Dodge_ch_392.truck","moskvich.truck","2107.truck","300ZX.truck","350Z.truck","2104.truck","115.truck","passat.truck","bcgtpm2.truck","continental.truck","m3.truck","e38.truck","cater500.truck","Chevroletss.truck","dmc12.truck","vip.truck","vip2.truck","vip3.truck","fer.truck","ToyotaSoarer.truck","Fordfiesta.truck","gavrilmv2r.truck","gavrilgv5_RA1PID.truck","delsol.truck","kalina_hatch.truck","ccx.truck","land200.truck","Maibatsu_Sport.truck","Maibatsu_LT.truck","Maibatsu.truck","rx7drift!.truck","mazda-rx-7-mad-mike.truck","3dc2eUID-MM-MagmaEdition-400-ls.truck","evoix.truck","evox2.truck","evox.truck","nissan240sx3.truck","nissan240sx3_dragster.truck","nissan240sx3_drifter.truck","nissan240sx3_fps.truck","nissan240sx3_drifter_fps.truck","Primera.truck","Nissan_GTR-R35.truck","nislaubos.truck","cuda.truck","R32.truck","rx7drifttune.truck","brzs.truck","brzs_blue.truck","supra.truck","supradrifttune.truck","Supra.truck","Supra2.truck","soarer.truck","21099.truck","Volvo242.truck","Volvo242drag.truck","Volvo242Street.truck","Volvo242WRC.truck","Race_Touareg.truck","2011H-519.truck","2015H-578.truck","2017H-603.truck","2014-565.truck","2016-590.truck","2009-1.truck","2009-2.truck","2010-1.truck","2010-2.truck","2011-1.truck","2011-2.truck","2012-1.truck","2012-2.truck","2013-1.truck","2014-1.truck","2015-1.truck","2016-1.truck","2017-1.truck","2018-1.truck","2008-1.truck","2007-1.truck","2006-1.truck","2005-1.truck","2005-2.truck","2006-2.truck","2007-2.truck","2008-2.truck","2013-2.truck","2013-3.truck","2013-4.truck","2014-2.truck","2015-2.truck","2016-2.truck","2017-2.truck","2018-2.truck","2019-1.truck","2019-2.truck","2003-432.truck","NSCbus1.truck","NSCbus34.truck","NSCbus42.truck","NSCbus9.truck","NSCbus93.truck","NSCbus94.truck","NSCbus36.truck","NSCbus32.truck","NSCbus59.truck","ICCE300Meshed_Beta2K.truck","ICCE300Meshed_Beta2K.TRUCK","2007-IC-CE-GCSNC-Bus-24.truck","2010ICCE-N.truck","2006ICCE-A.truck","2017ThomasC2-SEMINOLE-61615.truck","JPS2018-181.truck","LABS9580.truck","2014ICFE300.truck","2008BluebirdVision530.truck","2008BluebirdVision534.truck","2009BluebirdVision537.truck","2009BluebirdVision538.truck","2015BluebirdVision632.truck","2015BluebirdVision637.truck","2015BluebirdVision638.truck","2016BluebirdVision732.truck","2017BluebirdVision739.truck","2018BluebirdVision731.truck","2019BluebirdVision736.truck","2019BluebirdVision737.truck","2020BluebirdVision733.truck","1992BBB700-0392.truck","lacheti.truck","2019BBV24.truck","2018-TRRS-281.truck","2017BBV25.truck","2012BBV7.truck","1992BBC60-0292.truck","2018QISD1817.truck","2005QISD0523.truck","2003QISD0318.truck","2004-IC-CE-GCSNC-Bus-1.truck","2005ICCE200-HOLCOMB-137.truck","af25UID-aaadodgeviper.truck","CSMVPER.truck","CSMVPR2.truck","2018BluebirdVision738.truck","NBBC500-PUBLICR-5_WIM-I.truck","1998ThomasVista[I].truck","14-21.truck","1997GCPSTC2000.truck","1995ThomasMVPER.truck","2017ThomasHDX-SEMINOLE-61711.truck","2008ICCE300-179-SH-Lucini.truck","1997Crown9707.truck","GSX1.0.truck","2008C2J.truck","2010C2J.truck","2010C2A.truck","2014C2D.truck","2016C2N.truck","2006-IC-CE-GCSNC-Bus-22.truck","55-2015BBIntWorkstar.truck","2011ICCE300-3506.truck","2017ICCE300-3892.truck","1997BBFS651.truck","1998BBFS652.truck","2011CE300.truck","2018CE300.truck","2006FS65-24.truck","gavril_r_gold_legend.truck","2004A3CCS5804.truck","2009-Thomas-C2-NC.truck","2001-Thomas-FS65.truck","2014ThomasEFX.truck","2015ThomasEFX.truck","2016ThomasEFX.truck","2017ThomasEFX.truck","2018ThomasEFX.truck","1998BBFS651.truck","2019ThomasC2WY.truck","1999Crown9901.truck","2014ICCE300Handicap.truck","UPT1997BB3800.truck","1999Thomas3800.truck","HLS1998B21.truck","2004ICCE-Lucini-183.truck","HLS2003B38.truck","HLS2008B2.truck","HLS2002B31.truck","1969DodgeChargerRT.truck","79ChevyCamaroZ28.truck","54a9UID-2006Charger-Red.truck","54a9UID-2006ChargerADE.truck","54a9UID-2006ChargerDET.truck","54a9UID-2006ChargerLAPDST.truck","54a9UID-2006ChargerPPB.truck","54a9UID-2006Charger-Blue.truck","54a9UID-2006Charger-Black.truck","54a9UID-2006Charger-Silver.truck","2002ThomasFS65Cat7.truck","1949_Ford_Gasser.truck","2010Shelbygt500ERCAWD.truck","2010Shelbygt500ERCRWD.truck","C10lololol4.truck","evoix_saquet.truck","1979_Blazer_ERC.truck","bel.truck","ffrskb.truck","1999Crown9972.truck","2003BBChevy.truck","1997Crown9704.truck","2004BB3800-SERSD-250.truck","2004BB3800-SERSD-265.truck","2015BBV_SERSD-12.truck","AastonMartinVanquishf.truck","diablo.truck","2000ThomasMVPER.truck","2005-449.truck","C2(FS-5).truck","2004QISD0440.truck","2016-IC-CE-GCSNC-Bus-16.truck","2006-IC-CEGCSNC-Bus-19.truck","1999GCPSTC2000.truck","2007ICFE300505.truck","2012-IC-CE-Bus-20.truck","2006ICCE-Ds.truck","2006ICCE-Jn.truck","2007ICCE-D.truck","2008ICCE-JD.truck","2011ICCE-E.truck","2015ICCE-C.truck","2014ICCEACT.truck","1993-Ford-B700.truck","99-02.truck","2010ThomasC2NewYork.truck","2010ThomasC2NewYorkFPS.truck","2018-260.truck","2017QISD1739.truck","99-01.truck","2009ThomasC2ED706.truck","2016ThomasC2ED944.truck","1705.truck","2020ThomasC2CarolinaThomas.truck","2006C2141.truck","2006C2153.truck","2009C2299.truck","2006C2157.truck","2003QISD0321.truck","2019ICCE-ED41.truck","2013ICCE-ED26H.truck","2020ICCE-ED53.truck","2018BBV.truck","2010ICFE300.truck","audi90.truck","2004-IC-CE-GCSNC-Bus-7.truck","2010-IC-CE-GCSNC-Bus-9.truck","2006ICCEGCSNCBus17.truck","Bus25-04.truck","2015ICCE-1515ED.truck","Bus20-16.truck","2015ICCE300.truck","Bus19-10.truck","Bus7-12.truck","Bus50-08.truck","AstonMartin_v8_Vantage.truck","SheriffTaurus.truck","PoliceUndercoverTaurus.truck","PoliceTaurus.truck","WhiteTaurus.truck","OrangeTaurus.truck","NycCab.truck","Barwood.truck","GreyTaurus.truck","GreenTaurus.truck","CivTaurus.truck","BlueTaurus.truck","BlackTaurus.truck","crownviccop1.truck","Bus9-08.truck","Bus30-14.truck","Badass_Bandit.truck","Track_Bandit.truck","Street_Bandit.truck","1999BB3800991.truck","2005ICFE300.truck","pri_gold.truck","TCPSD60.truck","Lucini-CCS2919.truck","Lucini-MJ1772.truck","Lucini206.truck","DTC997.truck","1986-GMC-Diesel-6000.truck","1999-Freightliner-FS65.truck","2001ToyotaChaser.truck","08_C2_L.truck","2017DSS0321.truck","2017DSS1742.truck","2017DSS1743.truck","2003QISD0312.truck","2006ICFE300506.truck","2007ICFE300500.truck","2007ICFE300509.truck","2001A3CCS4901.truck","HECK-MEYERS2009ThomasC2191.truck","HECK-MEYERS2010ThomasC2165.truck","HECK-MEYERS2919.truck","HECK-MEYERS315.truck","Bus21.truck","UPT2017BBV.truck","2003ICCE-K867.truck","2018Handi-283.truck","1991MazdaRx7.truck","2010-Bluebird-All-American.truck","2010_BB_AA_RE_NC.truck","HECK-MEYERS947.truck","2015-572-P.truck","burnside_badass_convertible.truck","04BluebirdVISION.truck","Incandesent2005CE300MilfordSkin.truck","NoDistrict1.truck","NoDistrict2.truck","NoDistrict3.truck","NoDistrict4.truck","NoDistrict5.truck","NoDistrict6.truck","NoDIstrict7.truck","NoDistrict8.truck","NoDistrict9.truck","NoDistrict10.truck","2020BBVMrCRP.truck","NBBC400-PUBLICR-4BugFixes_WIM-I.truck","NBBC400-PUBLICR-4BugFixes_WM-I.truck","NBBC400-PUBLICR-4BugFix_WIM.truck","NBBC400-PUBLICR-4BugFix_WM.truck","NBBC400-Baldi2021.truck","ChrisBusModificationsAmTranFE-8.truck","AmTranRE.truck","Bald'sBus.truck","TONAWANDA2015CE300SPARE-47.truck","2016BBV.truck","BD642005CE200.truck","BD642006CE200.truck","BD642009CE300.truck","BD642010CE300.truck","BD642012CE300.truck","BD642013CE300.truck","bluebirdbus.truck","MEVS_2009_ICCE300_Bus43v4.truck","MEVS_2009_ICCE300_Bus43.truck","2000AmTranREBusHeritage66(HI).truck","2000AmTranREBusHeritage66(NWSA).truck","2000AmTranREBusHeritage66(WSA).truck","NBBC500-PUBLICR-6_WIM-I.truck","NBBC500-PUBLICR-6_WM-I.truck","NBBC500-PUBLICR-6_WIM.truck","NBBC500-PUBLICR-6_WM.truck","2000AmTranREBusHeritage66(HI)(NWSA).truck","ChrisBusModifications2020ThomasC2.truck","2020ThomasC2.truck","cbm-3800.truck","CBM2020CE300.truck","CE-300.truck","2006ICFE300-4.truck","2006ICFE300-2.truck","2006ICFE300-3.truck","2006ICRE300-1.truck","2006ICRE300-2.truck","CBM-BB3800-1.truck","2006ICRE300ND.truck","CBM-BB3800-2.truck","Ryzen_H7_FPS_Incandesent.truck","Howland1.truck","Howland84.truck","CBM2019ICRE-2.truck","NBBCINTERNATIONAL2485-PublicR-1.1BugFix.truck","1997GCPSCBM3800.truck","1996GCPS9627.truck","1996GCPS9622.truck","1996GCPS9623.truck","1996GCPS9624.truck","1996GCPS9625.truck","1997GCPS9711.truck","MEVS_2009_ICCE300_Bus43v2.truck","2004MEVS51-7.truck","2004MEVS64-7.truck","Bus33.truck","NBBC400-PUBLICR-3_WIM-I.truck","NBBC400-PUBLICR-3_WM-I.truck","NBBC400-PUBLICR-3_WIM.truck","NBBC400-PUBLICR-3_WM.truck","NBBC400-PUBLICR-5_WIM-I.truck","NBBC400-PUBLICR-5_WM-I.truck","NBBC500-PUBLICR-5_WIM.truck","NBBC500-PUBLICR-5_WM.truck","NBBCINTERNATIONAL2400-PublicR.truck","NBBC400-7.truck","NBBC400-PUBLICR.truck","2019NWBUSNBBC-6.truck","2019NWBUSNBBC-5.truck","NBBCtest.truck","2004NCPSSC6.truck","2004NCPSSC7.truck","2004NCPSSC8.truck","2004NCPSSC9.truck","2004NCPSSC10.truck","2004NCPSSC11.truck","2004NCPSSC12.truck","2004NCPSSC13.truck","2004NCPSSC14.truck","2004NCPSSC15.truck","2004NCPSSC16.truck","LABS0867.truck","LABS0952.truck","LABS1251.truck","LABS1368.truck","LABS1369.truck","LABS1370.truck","LABS1371.truck","LABS1658.truck","LABS1660.truck","NCPSSC1.truck","NCPSSC2.truck","NCPSSC3.truck","NCPSSC4.truck","NCPSSC5.truck","NCPSSC25.truck","NCPSSC26.truck","2005CE200.truck","2006CE200.truck","2009CE300.truck","2010CE300.truck","2012CE300.truck","2013CE300.truck","2006ICRE300ND-2.truck","Ryzen_X7000_NorthSchools50spare_Incandesent.truck","Ryzen_X7000_NorthSchools180-route_Incandesent.truck","SMFCS33.truck","RyzenFE.truck","Ryzen_X7000_FPS_Incandesent.truck","2019.truck","activity23.truck","activity24.truck","SEVS2003BBV.truck","SEVS2004BBV.truck","SEVS2005BBV.truck","SEVS2006BBV.truck","SEVS2007BBV.truck","SEVS2008BBV.truck","SEVS2009BBV.truck","SEVS2010BBV.truck","SEVS2011BBV.truck","SEVS2012BBV.truck","SEVS2013BBV.truck","SEVS2014BBV.truck","SEVS2015BBV.truck","SEVS2016BBV.truck","SEVS2017BBV.truck","SEVS2019BBV.truck","SEVS1996BBTC2000.truck","SEVS1997BBTC2000.truck","SEVS1997BBTC20009724.truck","SEVS1997BBTC20009725.truck","SEVS1998BBTC2000.truck","SEVS1999BBTC2000.truck","SEVS1999BBTC20009900.truck","SEVS1999BBTC20009940.truck","SEVS1999BB3800991.truck","SEVS2005ICFE300.truck","SEVS2006ICFE300.truck","SEVS2007ICFE300.truck","SEVS2008ICFE300.truck","SEVS2009ICFE300.truck","SEVS2010ICFE300.truck","37.truck","SEVS2005CE200.truck","SEVS2006CE200.truck","SEVS2009CE300.truck","SEVS2010CE300.truck","SEVS2012CE300.truck","SEVS2013CE300.truck","SEVS2019CE300.truck","2001SEVS0138.truck","2002SEVS0215.truck","2004SEVS0311.truck","2004SEVS0312.truck","2004SEVS0314.truck","2004SEVS0316.truck","2004SEVS0318.truck","2004SEVS0319.truck","2004SEVS0327.truck","2004SEVS0334.truck","2004SEVS0346.truck","KEVINSEVS2017ICCE.truck","CHRISSEVS2017ICCE.truck","RYANSEVS2017ICCE.truck","bus6.truck","bus7.truck","bus26.truck","bus27.truck","bus28.truck","bus29.truck","bus30.truck","bus31.truck","bus32.truck","bus33.truck","2009BBA3FE.truck","NBBCFE400.truck","NBBCRE400.truck","2008BBV.truck","UPT2014ThomasHDX.truck","UPT2018ThomasHDX.truck","1997BBGMC.truck","1997BBFS65.truck","1999ThomasMVPER.truck","AISD2001ThomasMVPER.truck","AISD2000ThomasMVPER.truck","AISD1999ThomasMVPER.truck","AISD1997ThomasMVPER.truck","AISD1996ThomasMVPER.truck","AISD1995ThomasMVPER.truck","2001ThomasMVPER.truck","2003A3.truck","2006ICFE300.truck","2006ICRE300FPS.truck","2006ICRE300.truck","1994-International-3800-DT408.truck","2006-IC-CE200.truck","2010-IC-CE300.truck","Prison.truck","Shortie.truck","Coach.truck","2010-IC-CE200.truck","Lucini237.truck","1998ThomasVista[NS].truck","2010ThomasC2-2339.truck","2003ICCE-J.truck","2016ICCE-ED66.truck","2019ICCE-ED42H.truck","2018BBV-TRRSD-162.truck","2005-BMW-E46.truck","91ThomasERFivestartrans.truck","ThomasInt3800.truck","2000A3CCS3100.truck","2006ICCE-E1H.truck","2018BBV-TRRSD-161.truck","2011ICCE-E801.truck","2004ICCE-E225.truck","2007ICCE-E643.truck","2001A3CCS1401.truck","2001A3CCS4801.truck","NCPS897.truck","2010ICCE-FL.truck","1103.truck","2016 Bus 154.truck","1997BBTC2000Bus111.truck","1999BBTC2000Bus118.truck","2004CROWN-FREIGHTLINER-TRRS-103.truck","cv-ICFE300Old.truck","109.truck","1503.truck","2003QISD0311.truck","1997GCPS9818.truck","Bus9-13.truck","2005BBFS65.truck","2019TRRSD-259.truck","2006ICCE-E13.truck","2007BBV-1407.truck","2008BBV-1508.truck","svtstang.truck","2007-IC-CE-GCSNC-Bus-25.truck","87 Murcury Grand Marquis.truck","2018 HECK-MEYERS HDX (1412).truck","2018 HECK-MEYERS HDX(1407).truck","bus25.truck","2006BBSBCV-1306.truck","2005BBV-1205.truck","2005ICFE300401.truck","2003ICFE300404.truck","09'BBV95.truck","dodgecaravan.truck","2005  Lamborghini Gallardo TEST MODEL.truck","2007ICCE300Handicap.truck","2003ICFE300402.truck","TCTC2008B4.truck","ASD_132059.truck","ASD_JCJT6526.truck","2015BluebirdVision637.truck","2002A3CCS0902.truck","2019BluebirdVision736.truck","2000A3CCS2800.truck","MPSBUS63.truck","MPSBUS29.truck","2004ThomasSaf-t-linerHDX.truck","HLS2018B5.truck","HLS1999B27.truck","HLS1998B21.truck","2018BluebirdVision738.truck","2002A3CCS3502JH.truck","HLS2008B16.truck","HLS2007B4.truck","ASD_132062.truck","HLS2003B38.truck","ASD_132064.truck","2001A3CCS4801.truck","ASD_132078.truck","2001A3CCS4901.truck","ASD_132073.truck","2002A3CCS0802.truck","2004ICFE300409.truck","ASD_132072.truck","2018ThomasSaf-t-linerHDX.truck","HLS1998B26.truck","2000A3CCS2500.truck","2019BluebirdVision737.truck","MPSBUS11.truck","2005ICFE300401.truck","HLS1998B22.truck","HLS2008B34.truck","HLS2006B40.truck","2004A3CCS5804.truck","2001A3CCS7001.truck","ASD_131720.truck","ASD_132067.truck","2015BluebirdVision638.truck","TCTC2004B3.truck","ASD_JCJT6527.truck","2001A3CCS3701.truck","2003A3CCS2203.truck","2004A3CCS2704.truck","HLS2008B6.truck","99BBFS65EN.truck","HLS1998B25.truck","2020BluebirdVision733.truck","HLS2007B3.truck","ASD_132066.truck","HLS1999B12.truck","MPSBUS28.truck","2009ThomasSaf-t-linerHDX.truck","2008BluebirdVision534.truck","2005ICFE300408.truck","HLS2016B33.truck","ASD_132070.truck","2015ThomasSaf-t-linerHDX.truck","2009BluebirdVision538.truck","2003A3CCS0403.truck","2003A3CCS1703.truck","2002A3CCS2602.truck","2007ICFE300500.truck","2007ICFE300507.truck","2002A3CCS2102.truck","2007ICFE300509.truck","2003ICFE300402.truck","ASD_132075.truck","MPSBUS9.truck","2005ThomasSaf-t-linerHDX.truck","HLS2008B2.truck","ASD_132060.truck","2008ThomasSaf-t-linerHDX.truck","MPSBUS41.truck","HLS2000B30.truck","HLS2003B32.truck","HLS2018B11.truck","HLS2006B41.truck","2000A3CCS3000.truck","HLS2001B7.truck","MPSBUS53.truck","2002A3CCS3202.truck","2006ICFE300506.truck","2018BluebirdVision731.truck","MPSBUS49.truck","2006ThomasSaf-t-linerHDX.truck","2001A3CCS1401.truck","2008BluebirdVision530.truck","2000A3CCS3100.truck","ASD_132068.truck","MPSBUS55.truck","2015BluebirdVision632.truck","HLS2008B35.truck","2004A3CCS4204.truck","2003A3CCS3403.truck","ASD_132077.truck","MPSBUS10.truck","MPSBUS43.truck","HLS2016B13.truck","MPSBUS45.truck","2016BluebirdVision732.truck","2010ThomasSaf-t-linerHDX.truck","ASD_132063.truck","HLS2000B14.truck","HLS2002B31.truck","HLS1998B19.truck","2009BluebirdVision537.truck","MPSBUS57.truck","2007ICFE300503.truck","1997GCPSTC2000.truck","2003A3CCS3903.truck","2007ICFE300505.truck","2003A3CCS4403.truck","MPSBUS12.truck","ASD_132074.truck","2005ICFE300406.truck","2003ICFE300404.truck","HLS2010B8.truck","2017BluebirdVision739.truck","2004A3CCS3304.truck","2003ThomasSaf-t-linerHDX.truck","ASD_132076.truck","2007ThomasSaf-t-linerHDX.truck","LLS1993B8.truck","LLS1997B13.truck","2006ICCE300Handicap.truck","2003-IC-CE200.truck","Lucini207.truck","Lucini159.truck","Lucini238.truck","2015BBV.truck","DTC525.truck","HUNTMAN 7.truck","Bus20-10.truck","2015ICCE-1315M.truck","cv-bluebird3800.truck","2016ICCE-E907.truck","2002BBFS65-1102.truck","2006ICCE.truck","2017BBV.truck","2008ThomasC2ED653.truck","2016-122.truck","2018-983.truck","2015-IC-CE-GCSNC-Bus-4.truck","2008-IC-CE300.truck","2007-Thomas-C2-NC.truck","2003CE-3-Drag.truck","195LBL-WB2014T3.truck","Lucini193.truck","LLS2007B5.truck","LLS2019B4.truck","Lucini913.truck","Lucini274.truck","Lucini2215.truck","LuciniCCS0518.truck","23-2002IC.truck","1993_335.truck","LuciniCCS6114.truck","07_C2_L.truck","14_C2_L.truck","10_C2_L.truck","C-2005-51.truck","C-2014-03.truck","C-2008-18-H.truck","17_C2_L_SE.truck","vh-03fs65.truck","NC16CEL.truck","2005 ic ce personal f.t.a.g.truck","06impalaunmarked.truck","15 SLT MVP.truck","C2 105 CEO.truck","2015dmax4wd.truck","2015dmax4wdmudder.truck","2015dmax2wdslammed.truck","2015dmax4wdslammed.truck","2015dmax2wd.truck","2015dmax4wdcencalstyle.truck","2015dmax4wdflatbed.truck","NCBC18.truck","2015-IC-CE GCSNC-Bus-14.truck","hazzard.truck","79ChevyCamaroZ28E.truck","BlossomTransportation2011BlueBirdAllAmericanFeHandicappedAccess.truck","Lucini203.truck","Lucini-MJ1711.truck","Lucini208.truck","Lucini-CCS5718.truck","Lucini-CCS0315.truck","Lucini-CCS5211.truck","2019ICCE300NEW.truck","Lucini905.truck","Lucini507.truck","Lucini401.truck","2019TRRSD-262.truck","2005ICCE300NEW.truck","2002QISD0215.truck","2006ICCEFPS.truck","Jason2006CE200-181.truck","2008ICFE-274.truck","TRRS-177.truck","2009ThomasC2ED6246.truck","2010ThomasC2ED6250.truck","2013ThomasC2ED6252.truck","2013ThomasC2ED6253.truck","2013ThomasC2ED6254.truck","2015ThomasC2ED6258.truck","2019ThomasC2EDCrewdz.truck","2017H-603.truck","2007-1.truck","2008-1.truck","2014-1.truck","2013-1.truck","2003-432.truck","2009-1.truck","2020.truck","2011-1.truck","2005-1.truck","2019-1.truck","2010-1.truck","2012-1.truck","2018-1.truck","2017-1.truck","2016-1.truck","2016-590.truck","2014-565.truck","2015H-578.truck","2011H-519.truck","2006-1.truck","2015-1.truck","2018-18-5.truck","NCBC21.truck","2017ICCE-MT.truck","2004NCPSBC12.truck","08policetahoe.truck","2019TRRSD-263.truck","2019TRRSD-261.truck","FS2019ICCEHX8945.truck","FS2019ICCEHX8946.truck","FS2020ICCEHX8844.truck","2019BBVFSHD4566.truck","2019BBVFSHD4568.truck","995BBGMC-0495.truck","1998BB3800-0698.truck","2002BBFS65-1002.truck","LABS0836.truck","2007ICCE200-STOUGHTON-071232.truck","2016ThomasC2-STOUGHTON-8639.truck","Lucini205.truck","2004CROWN-FREIGHTLINER-TRRS-108.truck","FST2010C2 10-07.truck","FST2018C2 10-01.truck","1996ThomasMVPER.truck","2017Activity(Universal Shuttle).truck","2018Handi-671.truck","2015 IC CE 300.truck","2015QISD1505.truck","2021QISD2130.truck","2006QISD0633.truck","2010QISD1021.truck","2020QISD2027.truck","2015QISD1526.truck","2005QISD0508.truck","2007C2cbm.truck","Lucini194.truck","LuciniCCS2419.truck","Lucini275.truck","LuciniM&J2851.truck","2018BBV-165.truck","2007 C2 162.truck","2017 C2 166.truck","2018Handi-321.truck","Lucini192.truck","DTC506.truck","Lucini204.truck","AGRP2014CE.truck","2018BBV-TRRSD-168.truck","2018ICCE300NEW.truck","TRRS-116.truck","2010ICCE-ED22.truck","2019TRRSD-258.truck","2002-2.truck","gavrilmz2rGT1Ravenwest.truck","gavrilmz2rGT1.truck","2020M3CBMCE300.truck","2016-IC-CE-GCSNC-Bus-13.truck","Hauck38.truck","11-04.truck","2010ThomasC2Handi.truck","2011ThomasHDX-Serengeti-Bus60.truck","bmw-e39-m5-2004.truck","vh-01fs65.truck","2019ICCE300Handicap.truck","NCPSSfORD_7.truck","CBMNCBUS1.truck","2004NCPSBC13.truck","2007DSS0730.truck","CBMNCBUS1.truck","vh-01fs65101.truck","2006QISD0632.truck","2007BluebirdVision.truck","2010C2308.truck","TCPSD162.truck","TCPSD28.truck","406.truck","8017.truck","vh-GMCThomas.truck","vh-05fs65.truck","3800D267.truck","8030.truck","vh-b800.truck","2019C2560.truck","2010C2325.truck","2010C2308.truck","1999BBTC20009900.truck","1999BBFS653.truck","Bus982.truck","2004FS65-SERSD-UN.truck","2006FS65-SERSD-17.truck","CBM2020ICRE-2.truck","2010C2325.truck","2019C2560.truck","UPT1997BBFS65.truck","UPT1998BBFS65.truck","UPT1999BBFS65.truck","UPT2000BBFS65.truck","UPT2001BBFS65.truck","UPT2002BBFS65.truck","UPT1997BB3800.truck","UPT1998BB3800.truck","UPT1999BB3800.truck","UPT2000BB3800.truck","UPT2001BB3800.truck","UPT2002BB3800.truck","UPT2003BluebirdChevy.truck","UPT2002BluebirdChevy.truck","UPT2001BluebirdChevy.truck","UPT1999BluebirdChevy.truck","UPT1998BluebirdChevy.truck","UPT1997BluebirdChevy.truck","UPT2019BBV.truck","UPT2017BBV.truck","UPT2015BBV.truck","UPT2018BBV.truck","UPT2016BBV.truck","UPT2014BBV.truck","UPT2010BBV.truck","UPT2009BBV.truck","UPT2014ThomasHDX.truck","UPT2018ThomasHDX.truck","UPT2012ThomasHDX.truck","UPT2005ThomasHDX.truck","UPT2006ThomasHDX.truck","UPT2007ThomasHDX.truck","2001Thomas3800.truck","1994Thomas3800.truck","1995Thomas3800.truck","1996Thomas3800.truck","1997Thomas3800.truck","1998Thomas3800.truck","1999Thomas3800.truck","2000Thomas3800.truck","2002Thomas3800.truck","2003Thomas3800.truck","Firedepartment_station2.load","03-14.truck","03-41.truck","03-65.truck","03-75.truck","03-96.truck","04-42.truck","04-58.truck","04-61.truck","04-85.truck","04-99.truck","1997BBFS65.truck","1997BBFS651.truck","1997BBFS652.truck","1998BBFS65.truck","1998BBFS651.truck","1998BBFS652.truck","1999BBFS65.truck","1999BBFS651.truck","1999BBFS652.truck","1999BBFS653.truck","1998BlueBirdGMC.truck","1998BlueBirdGMC2.truck","1997BlueBirdGMC3.truck","1997BlueBirdGMC4.truck","1999BlueBirdGMC5.truck","2003BBChevy.truck","2003BBChevy7.truck","2003BBChevy8.truck","2003BBChevy9.truck","2004BBChevy10.truck","2006ICCE300Handicap.truck","2007ICCE300Handicap.truck","2009ICCE300Handicap.truck","2010ICCE300Handicap.truck","2011ICCE300Handicap.truck","2012ICCE300Handicap.truck","2014ICCE300Handicap.truck","2015ICCE300Handicap.truck","2017ICCE300Handicap.truck","2019ICCE300Handicap.truck","2006ICFE300.truck","2007ICFE300.truck","2008ICFE300.truck","2009ICFE300.truck","2010ICFE300.truck","2005ICFE300.truck","1997Crown9707.truck","1997Crown9743.truck","1998Crown9823.truck","1997Crown9704.truck","1998Crown9856.truck","1998Crown9875.truck","1999Crown9999.truck","1999Crown9901.truck","1999Crown9908.truck","1999Crown9972.truck","1995ThomasMVPER.truck","1996ThomasMVPER.truck","1997ThomasMVPER.truck","1999ThomasMVPER.truck","2000ThomasMVPER.truck","2001ThomasMVPER.truck","2005BB3300SBCV0591.truck","2001BB3300SBCV0186.truck","2002BB3300SBCV0217.truck","2003BB3300SBCV0334.truck","2004BB3300SBCV0443.truck","2005BB3300SBCV0560.truck","2006BB3300SBCV0692.truck","2002BB3300SBCV0234.truck","2003BB3300SBCV0371.truck","2004BB3300SBCV0475.truck","2005BB3300SBCV0598.truck","SCPS1995ThomasMVPER.truck","SCPS1996ThomasMVPER.truck","SCPS1997ThomasMVPER.truck","SCPS1998ThomasMVPER.truck","SCPS1999ThomasMVPER.truck","SCPS2000ThomasMVPER.truck","SCPS2001ThomasMVPER.truck","SCPS2002ThomasMVPER.truck","SCPS2003ThomasMVPER.truck","SCPS2004ThomasMVPER.truck","2000ThomasMVPERSCPS.truck","2001ThomasMVPERSCPS.truck","1999BBTC2000.truck","1997BBTC2000.truck","1997BBTC20009725.truck","1997BBTC20009724.truck","1999BBTC20009940.truck","1999BBTC20009900.truck","1998BBTC2000.truck","1996BBTC2000.truck","2007ThomasC2WB.truck","2007ThomasC2WY.truck","2007ThomasC2YY.truck","2008ThomasC2WB.truck","2008ThomasC2YB.truck","2008ThomasC2YY.truck","2009ThomasC2YB.truck","2010ThomasC2YB.truck","2013ThomasC2WY.truck","2014ThomasC2WY.truck","2014ThomasC2YY.truck","2015ThomasC2WB.truck","2015ThomasC2YB.truck","2015ThomasC2YY.truck","2018ThomasC2WB.truck","2018ThomasC2YB.truck","2019ThomasC2WB.truck","2019ThomasC2WY.truck","2019ThomasC2YB.truck","2019ThomasC2YY.truck","2013ICCE300NEW.truck","2012ICCE300NEW.truck","2014ICCE300NEW.truck","2015ICCE300NEW.truck","2011ICCE300NEW.truck","2016ICCE300NEW.truck","2017ICCE300NEW.truck","2018ICCE300NEW.truck","2019ICCE300NEW.truck","2010ICCE300NEW.truck","2009ICCE300NEW.truck","2008ICCE300NEW.truck","2007ICCE300NEW.truck","2006ICCE300NEW.truck","2005ICCE300NEW.truck","2015CE300.truck","2019CE300.truck","2018CE300.truck","2017CE300.truck","2016CE300.truck","2014CE300.truck","2013CE300.truck","2012CE300.truck","2011CE300.truck","2010CE300.truck","2009CE300.truck","2008CE300.truck","2007CE300.truck","2006CE300.truck","2005CE300.truck","2019CE3002.truck","2018CE3002.truck","2017CE3002.truck","2016CE3002.truck","2009CE3002.truck","2001ThomasFS653126.truck","2002ThomasFS653126.truck","2003ThomasFS653126.truck","2004ThomasFS653126.truck","2005ThomasFS653126.truck","2001ThomasFS65Cat7.truck","2002ThomasFS65Cat7.truck","2003ThomasFS65Cat7.truck","2004ThomasFS65Cat7.truck","2005ThomasFS65Cat7.truck","2007BBV.truck","2013BBV.truck","2014BBV.truck","2015BBV.truck","2016BBV.truck","2017BBV.truck","2018BBV.truck","2019BBV.truck","2012BBV.truck","2011BBV.truck","2010BBV.truck","2009BBV.truck","2008BBV.truck","2006BBV.truck","2005BBV.truck","2004BBV.truck","2003BBV.truck","14'BBV95.truck","2002ICSB0215.truck","2012-IC-CE GCSNC-Bus-3.truck","2009-498.truck","CCS2800.truck","2017DSS1739.truck","1998BB3800-0798.truck","1995BBGMC-0495.truck","CCS3608.truck","2018ICCE300-3922.truck","2003QISD0319.truck","APS2.truck","APS9.truck","2019IC-CE -Bus 13-02.truck","CCS2200.truck","APS11.truck","2002BBChevy-0802.truck","APS16.truck","CV200.truck","2016-IC-CE-GCSNC-Bus-11.truck","2004CBM0427.truck","2006-IC-CE GCSNC-Bus-20.truck","TRRS-135.truck","APS11.truck","TRRS-125.truck","2017BBV-RVCS-6902.truck","55-2015BBIntWorkstar_y_w_roof.truck","MPSBUS8.truck","APS12.truck","2005QISD0506.truck","2010QISD1004.truck","2017QISD1707.truck","2005QISD0522.truck","2010QISD1004.truck","2008QISD0810.truck","2020ThomasC2ED868.truck","2002-132.truck","8047.truck","kitt.truck","logan.truck","1986-Ford-B700.truck","1981-Chevrolet-V8-60.truck","1998-Freightliner-FS65.truck","01-FS65.truck","2017QISD1705.truck","2021ThomasC2-SEMINOLE-J.truck","2016ThomasC2-SEMINOLE-61521.truck","2016ThomasC2-SEMINOLEH.truck","2019ICCE-SEMINOLE-61904.truck","2018ThomasHDX-SEMINOLE-61708.truck","2019ICCE-SEMINOLE-61905.truck","2019ThomasHDX-SEMINOLE-61810.truck","TRRS-159.truck","2018BBV-SEMINOLE-61704.truck","2017QISD1707.truck","APS13.truck","CCS1506.truck","1969DodgeChargerRTStreetDrag.truck","vh-05fs6527.truck","2015-IC-CE-GCSNC-Bus-5.truck","APS6.truck","2018ICCE-ED997.truck","2004FS65-28.truck","3800D273.truck","3800D200.truck","vh-99fs651141.truck","ZAZtavria.truck","2101.truck","2019ICCE-SEMINOLE-61908.truck","2019ICCE-SEMINOLE-61907.truck","2019ICCE-SEMINOLE-61901.truck","2019ICCE-SEMINOLE-61902.truck","2019ICCE-SEMINOLE-61906.truck","2019ICCE-SEMINOLE-61908.truck","2019ICCE-SEMINOLE-61907.truck","2020ThomasC2-PASCO COUNTY SCHOOLS-62001.truck","burnsidelimolowerfaster.truck","2012ICCE300-3694.truck","2012ICCE300-3685.truck","2011ICCE300-3666.truck","11.truck","m3e42.truck","veyron.truck","1995-International-3800-DT466.truck","ZAZ.truck","gavril_r_sakura_bunny.truck","ae86_trueno_1st-3rd.truck","ae86_trueno_4th-6th.truck","Thomas-C2.truck","CBMBBV.truck","2016ThomasC2ED.truck","Murcielago2.truck","2021ThomasHDX-SEMINOLE-62006.truck","5-2015BBIntWorkstar_y_y_roof.truck","55-2015BBIntWorkstar_b_y_roof.truck","1999 Thomas Vista.truck","08_C2_LS.truck","2011BBD3FEhandy.truck","2011BBD3RE.truck","2011BBD3Church.truck","04-Thomas-FS65.truck","2004-IC-RE-RB.truck","BakuganDragonoidBreakable.truck","BakuganDragonoidIceBreakable.truck","TCPSD23.truck","TCPSD25.truck","BakuganDragonoid2019.truck","IceBakuganDragonoid2019.truck","BakuganDragonoidMurphy2019.truck","BakuganDragonoid2019Aurelus.truck","BakuganMatteBlackSexyEdition.truck","1989BBS1800-0189.truck","1995BBGMC-0595.truck","1989BBS1800-0189.truck","Lucini201.truck","006ICCE-J174.truck","2004ICCE-G135.truck","CCSD190519.truck","2010ThomasC2ED753.truck","2007C2SLTI50.truck","2020C2SLTI51.truck","2013ICCE-ED12.truck","2018ICCE-ED14.truck","2018TRRS-283.truck","2010CBMCE2.truck","2020ThomasC2ED420.truck","2009ICCE300-3462.truck","2004MEVS64-8.truck","PCS Bus 17.truck","PCS Bus 14.truck","2014ICCEFPS.truck","ICTESTNS.truck","NCPS176.truck","2004ICCE200248.truck","FS65R1-1998ThomasMVPEF.truck","2010ICCE-C10.truck","gavril_r_rhd.truck","2009ThomasC2ED751.truck","CBM4.truck","DTC837.truck","2019QISD1902.truck","DTC546.truck","DTC556.truck","DTC817.truck","DTC917.truck","DTC847.truck","DTC546.truck","2015_DSS_1526.truck","2004MEVS64-8.truck","2006-ICCE-GCSNC-Bus-8.truck","2004MEVS64-8.truck","2004NCPSBC11.truck","2001BB3800CBM.truck","urvan.truck","vick.truck","Collins785.truck","BakuganDraganoid2019.truck","2004NCPSBC10.truck","2005SBCV-ST32.truck","NCSFC 191.truck","NCS Forsyth County 3001.truck","DSS525.truck","DSS556.truck","2021QISD2128.truck","2013ThomasC2ED82.truck","2018ThomasC2ED10.truck","2015ThomasC2ED8069.truck","55-2015BBIntWorkstar_I.truck","fprd_tr.truck","55-2015BBIntWorkstar_y_y_roof.truck","55-2015BBIntWorkstarFS.truck","55-2015BBIntWorkstar_S2.truck","BBV1005.truck","BBV997.truck","BBV963.truck","BBV956.truck","BBV960.truck","2016BBV5.truck","2016BBV7.truck","2007BBARE_W_Y.truck","2005ICCEHandi-SEMINOLE-70329.truck","2017BBV-SEMINOLE-61705.truck","2017BBV-SEMINOLE-61703.truck","2005ICCEHandi-SEMINOLE-70325.truck","2017BBV-SEMINOLE-61703.truck","2005ICCEHandi-SEMINOLE-70325.truck","NCTrans2003ThomasFS65.truck","2016ThomasC2-PASCO COUNTY SCHOOLS-61515.truck","DSS197.truck","20030327.truck","2002-1.truck","Ryzen_X8000_NorthSchools50spare_Incandesent.truck","Ryzen_X8000_NorthSchools180-route_Incandesent.truck","DURHAM2013ICCE300.truck","14-2.truck","14-1.truck","CDS200789141.truck","2017QISD1726.truck","CDS2008157.truck","QISDVic.truck","Ryzen_X8000_NorthSchools180-route_Incandesent.truck","DSS439.truck","DSS476.truck","2003SEVS0314.truck","21-92.truck","21-1.truck","2007FS65.truck","Jason2005CE200-180.truck","2006CE200-181.truck","20030316.truck","20030314.truck","2005CE200-180.truck","chevy10blazer2.truck","21-132.truck","3800J569.truck","2020ICCE-ED1002.truck","2018BBV-TRRSD-172.truck","Bus3-08.truck","Buffalo03ICCE208433.truck","EBPS9.truck","2018BBV19.truck","2005QISD0527.truck","2019ICCE300P.truck","FST2012C2 10-08.truck","FST2010C2 10-14.truck","FST2016C2 10-04.truck","2017BBV_FirstStudent-86.truck","2016BBV_FirstStudent-87.truck","FS8051.truck","FST2015C2 10-18.truck","2003FS65-26.truck","66.truck","85.truck","88.truck","2010ICCE300-3492.truck","21-90.truck","21-132.truck","2018-612.truck","2015-576.truck","2008-489.truck","TRRS 2017 Thomas C2.truck","TRRS177.truck","2017BBV-RVCS-6609.truck","2012ICCE300-3456.truck","20020215.truck","DSS817.truck","2006CE200-181.truck","87.truck","TRRS177.truck","FST2016C2 10-04.truck","FST2016C2 10-09.truck","2002ThomasMVPER-172.truck","3800D264.truck","2002ThomasMVPER-172.truck","2016ThomasC2-SEMINOLE-61529.truck","CollinsNew2010ICCE.truck","TCPSD79.truck","2018TRRS-212.truck","MPSBUS2.truck","2014_C2_SLTI_13.truck","MPSBus54.truck","2000-Corbeil-FSC.truck","2001-Corbeil-shorty.truck","2001-Corbeil-DRAG.truck","2000-Corbeil-highheadroom.truck","2020transbus2056.truck","CLSD2015CE300.truck","ASD_2014ThomasEFX-140180.truck","MPSBUS66.truck","MPSBus55.truck","MPSBUS65.truck","86.truck","2012ThomasC235.truck","MPSBUS2.truck","HECK MEYERS 20.truck","DeshaunC2.truck","CollinsNew2010ICCE.truck","LABS1254.truck","LABS1661.truck","LABS1590.truck","LABS1661.truck","LABS1663.truck","LABS1589.truck","2005DSS0529.truck","2006ICCE-J.truck","ACXcustom.TRUCK","74.truck","58.truck","67.truck","59.truck","2002DSS0215.truck","UPS.truck","HondaPreludeWhite.truck","gallardotest.TRUCK","CCS4710.truck","2007SCPSC2.truck","1234.truck","84.truck","PB-37-18.truck","APS8.truck","11' porsche 911gt3.truck","2002ThomasMVPER-173.truck","EBPS1.truck","EBPS25.truck","TPS4.truck","APS15.truck","TPS3.truck","APS 30.truck","APS26.truck","APS10.truck","MTI807.truck","2011JTHS7.truck","2012JTHS10.truck","2013JTHS8.truck","2014JTHS1.truck","2016JTHS4.truck","2016JTHS6.truck","2017JTHS2.truck","2017JTHS5.truck","2018JTHS3.truck","2020JTHS9.truck","CollinsNew2008ICCEACT.truck","2016ThomasC2-BCS-932.truck","2017Activity.truck","2017ICCE300-HOLCOMB-2109.truck","Blue_Bird_Vision_Activity_Bus_CT.truck","2020SCSD4.truck","2016ThomasC2-BCS-932.truck","2021QISD2129.truck","LABS1255.truck","2010CBMCE.truck","2018QISD1820.truck","93_chevy_silverado.truck","PCS Bus 12.truck","2019FSC2-114.truck","2019FSC2-117.truck","21 SLT HDX.truck","CBMMEVS43NEW.truck","2018C2-MPS-18.truck","2018C2-MPS-27.truck","2004NCPSBC9.truck","3.truck","UPT2015BBTX4FE.truck","2011ICCE-MPS-32-H.truck","1999 MVP 15.truck","2016ThomasC2-SEMINOLE-61502.truck","RidleySchoolDistrictBus58.truck","PCRummellANASDOAK.truck"
}; 
streamValidation bannedCars(@streamFilterList, BLACKLIST);


// Our main function (never remove this, even when it does nothing useful!)
void main()
{
	server.Log("The script file is working :D");
	server.setCallback("playerAdded", "authWarning_playerAdded", null);
}

// Add this somewhere else, for example at the very bottom of ExampleScript.as
void authWarning_playerAdded(int uid)
{
	if((server.getUserAuthRaw(uid)&(AUTH_ADMIN|AUTH_MOD))>0)
		server.say(server.getUserName(uid)+" is a server "+server.getUserAuth(uid), TO_ALL, FROM_HOST);
}